@@ -425,6 +425,8 @@ class PyUnitTestChecker(PyTestChecker):
                 total += cmd.parser.total
                 for rtype in testresults:
                     testresults[rtype] += getattr(cmd.parser, rtype)
+                if cmd.status == NODATA:
+                    self.writer.error('no test found', path=test_file)
                 status = self.merge_status(status, cmd.status)
         self.execution_info(total, testresults)
         return status
