@@ -25,7 +25,7 @@ from logilab.common.tasksqueue import LOW, Task
 from logilab.common.configuration import format_option_value
 
 from apycotbot import SetupException, ConfigError, get_registered
-from apycotbot.utils import (SKIPPED, FAILURE, ERROR, KILLED,
+from apycotbot.utils import (SUCCESS, SKIPPED, FAILURE, ERROR, KILLED,
                              EnvironmentTrackerMixin, Command)
 from apycotbot.checkers import MissingChecker
 from apycotbot.repositories import get_repository
@@ -329,7 +329,7 @@ class Test(EnvironmentTrackerMixin):
         self.resource_ctrl.setup_limit()
         checkers = iter(self.checkers)
         skipmsg = "Unknown error in unknown check"
-        globstatus = FAILURE
+        globstatus = SUCCESS
         try:
             writer = self.writer
             for checker in checkers:
@@ -412,6 +412,10 @@ class Test(EnvironmentTrackerMixin):
             finally:
                 try:
                     self.writer.end_test(status, self.archive and self.tmpdir)
+                except:
+                    # XXX log error
+                    pass
+                try:
                     self.clean()
                 except:
                     # XXX log error
