@@ -17,6 +17,7 @@ from tempfile import TemporaryFile
 
 from Pyro import errors
 
+from logilab.common.textutils import splitstrip
 from logilab.common.logging_ext import set_log_methods
 from logilab.common.pyro_ext import ns_group_and_id
 
@@ -120,12 +121,14 @@ def connection_infos():
             if instinfo.get('pyro-ns-group', nsgroup) != nsgroup:
                 raise ConfigError('conflicting values for pyro-ns-group')
             nsgroup = instinfo.get('pyro-ns-group', nsgroup or 'cubicweb')
-            qinstid = ':%s.%s' % (nsgroup, instid)
+            if nsgroup[0] != ':':
+                nsgroup = ':' + nsgroup
+            qinstid = '%s.%s' % (nsgroup, instid)
             if 'aliases' in instinfo:
-                for alias in get_csv(instinfo['aliases']):
+                for alias in splitstrip(instinfo['aliases']):
                     aliasnsgroup, aliasinstid = ns_group_and_id(
                         alias, defaultnsgroup=nsgroup)
-                    qalias = ':%s.%s' % (aliasnsgroup, aliasinstid)
+                    qalias = '%s.%s' % (aliasnsgroup, aliasinstid)
                     assert qalias not in aliases, 'duplicated alias %s' % qalias
                     aliases[qalias] = qinstid
             if cwinstid != qinstid:
